@@ -7,14 +7,14 @@ void Generator::debug(ostream &out) const
 
     key(out);
 
-    out << "if (d_debug__)\n" <<
+    out << "if (d_debug_)\n" <<
         setw(d_indent + 4) << "" << flush;
 
     if (*d_line.rbegin() != '+')
-        out <<  "s_out__ << " << d_line << " << '\\n' << dflush__;\n";
+        out <<  "s_out_ << " << d_line << " << '\\n' << dflush_;\n";
     else
     {
         d_line.resize(d_line.length() - 1);
-        out <<  "s_out__ << " << d_line << ";\n";
+        out <<  "s_out_ << " << d_line << ";\n";
     }
 }
