@@ -44,6 +44,7 @@ class Generator
     bool d_printTokens;
     bool d_threadSafe;
 
+                                        // polymorphic key -> C++ type
     std::unordered_map<std::string, std::string> const &d_polymorphic; 
 
     mutable Writer d_writer;                // maintains its own const-ness
@@ -116,6 +117,8 @@ class Generator
         void polyIncludes(std::ostream &out) const;
         void polymorphicCode(std::ostream &out) const;
         void polymorphicSpecializations(std::ostream &out) const;
+        void polymorphicOpAssignDecl(std::ostream &out) const;
+        void polymorphicOpAssignImpl(std::ostream &out) const;
         void preIncludes(std::ostream &out) const;
         void print(std::ostream &out) const;
         void prompt(std::ostream &out) const;
