@@ -3,6 +3,6 @@
 void Parser::blkSTYPEW(string const &ruleType, Production const &prod)
 {
     wmsg << '`' << &prod << 
-            "': installed $$ = STYPE__{} action block" << endl;
+            "': installed $$ = STYPE_{} action block" << endl;
     blkSTYPE(ruleType, prod);
 }
