@@ -11,7 +11,7 @@
 class NonTerminal;
 class Terminal;
 class Symbol;
-class Options;
+struct Options;
 class AtDollar;
 
 namespace FBB
