@@ -30,11 +30,11 @@ $insert 4 scannerobject
         void exceptionHandler(std::exception const &exc);
 
     // support functions for parse():
-        void executeAction__(int ruleNr);
-        void errorRecovery__();
-        void nextCycle__();
-        void nextToken__();
-        void print__();
+        void executeAction_(int ruleNr);
+        void errorRecovery_();
+        void nextCycle_();
+        void nextToken_();
+        void print_();
 };
 
 $insert namespace-close
